@@ -124,6 +124,9 @@ autoini <- function (capthist, mask, detectfn = 0, thin = 0.2, tol = 0.001,
         list(D=NA, g0=NA, sigma=NA)
     else {
         
+        ## treat capped as proximity 2022-04-13
+        dettype[dettype==8] <- 1  
+        
         ## wt is the number of opportunities for capture given binary usage
         wt <- apply(usge>0, 1, sum)
 
